package com.landray.kmss.sys.attachment.actions;

import com.landray.kmss.web.config.IActionConfig;
import java.util.Map;
import com.landray.kmss.common.service.IBaseService;
import com.landray.kmss.web.config.ForwardConfig;
import com.landray.kmss.sys.attachment.util.ImageCropUtil;
import org.apache.commons.lang.StringEscapeUtils;
import net.sf.json.JSONArray;
import com.landray.kmss.util.KmssReturnPage;
import net.sf.json.JSONObject;
import com.landray.kmss.util.KmssMessages;
import com.landray.kmss.sys.log.util.UserOperHelper;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.common.forms.IExtendForm;
import com.landray.kmss.common.test.TimeCounter;
import com.landray.kmss.web.action.ActionForward;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.attachment.service.ISysAttImageCropService;
import org.slf4j.Logger;
import com.landray.kmss.common.actions.ExtendAction;

public class SysAttImageCropAction extends ExtendAction
{
    private final Logger logger;
    private ISysAttImageCropService sysAttImageCropService;
    
    public SysAttImageCropAction() {
        this.logger = LoggerFactory.getLogger(this.getClass());
    }
    
    protected ISysAttImageCropService getServiceImp(final HttpServletRequest request) {
        if (this.sysAttImageCropService == null) {
            this.sysAttImageCropService = (ISysAttImageCropService)this.getBean("sysAttImageCropService");
        }
        return this.sysAttImageCropService;
    }
    
    public ActionForward addCrop(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-addCrop", true, (Class)this.getClass());
        try {
            response.setCharacterEncoding("utf-8");
            final String imgInfo = this.getServiceImp(request).addCrop((IExtendForm)form).toString();
            if (StringUtil.isNotNull(imgInfo)) {
                response.getWriter().append(imgInfo);
                UserOperHelper.setOperSuccess(true);
            }
            UserOperHelper.setOperSuccess(true);
        }
        catch (final Exception e) {
            this.logger.error("att image crop error!", e);
            UserOperHelper.setOperSuccess(false);
        }
        TimeCounter.logCurrentTime("Action-addCrop", false, (Class)this.getClass());
        return null;
    }
    
    public ActionForward cancelCrop(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-cancelCrop", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            final String attId = request.getParameter("attId");
            if (StringUtil.isNotNull(attId)) {
                this.getServiceImp(request).updateCancel(attId);
                request.setAttribute("lui-source", (Object)JSONObject.fromObject((Object)"{'scuccess' : 'true'}"));
            }
        }
        catch (final Exception e) {
            e.printStackTrace();
            messages.addError((Throwable)e);
        }
        TimeCounter.logCurrentTime("Action-cancelCrop", false, (Class)this.getClass());
        if (messages.hasError()) {
            KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
    
    public ActionForward listCrop(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-listCrop", true, (Class)this.getClass());
        try {
            final String modelId = request.getParameter("fdModelId");
            final String modelName = request.getParameter("fdModelName");
            JSONArray array = new JSONArray();
            if (!StringUtil.isNull(modelId)) {
                final String[] keys = this.abtainCropKeys(request);
                array = this.getServiceImp(request).findByKeys(modelName, modelId, keys);
                if (array.isEmpty()) {
                    array = this.getServiceImp(request).findByKeys(modelName, modelId, new String[] { "zonePersonInfo" });
                    if (!array.isEmpty()) {
                        final JSONObject obj = (JSONObject)array.remove(0);
                        final String id = obj.get("value").toString();
                        String[] array2;
                        for (int length = (array2 = keys).length, i = 0; i < length; ++i) {
                            final String key = array2[i];
                            final JSONObject json = new JSONObject();
                            json.accumulate("key", (Object)StringEscapeUtils.escapeHtml(key));
                            json.accumulate("value", (Object)id);
                            array.add((Object)json);
                        }
                    }
                }
            }
            response.setHeader("content-type", "application/json;charset=utf-8");
            response.setCharacterEncoding("utf-8");
            response.getWriter().append(array.toString());
        }
        catch (final Exception e) {
            this.logger.error("find image crop error!", e);
        }
        TimeCounter.logCurrentTime("Action-listCrop", false, (Class)this.getClass());
        return null;
    }
    
    private String[] abtainCropKeys(final HttpServletRequest request) {
        final String fdKey = request.getParameter("fdKey");
        final String fdCropKeys = request.getParameter("fdCropKeys");
        String[] tempKeys = null;
        if (StringUtil.isNull(fdCropKeys)) {
            tempKeys = ImageCropUtil.CROP_KEYS;
        }
        else {
            tempKeys = fdCropKeys.split(";");
        }
        for (int i = 0; i < tempKeys.length; ++i) {
            tempKeys[i] = String.valueOf(fdKey) + tempKeys[i];
        }
        return tempKeys;
    }
    
    public ActionForward imageInfo(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-imageInfo", true, (Class)this.getClass());
        try {
            final String attId = request.getParameter("attId");
            response.setCharacterEncoding("utf-8");
            response.getWriter().append(this.getServiceImp(request).obtainImageInfo(attId).toString());
        }
        catch (final Exception e) {
            this.logger.error("get width and height of image  error!", e);
        }
        TimeCounter.logCurrentTime("Action-imageInfo", false, (Class)this.getClass());
        return null;
    }
}
